"""General template for the download report"""
from string import Template
from typing import Dict

from ws_metrics.reporting.interfaces import RTemplate
from ws_metrics.schema import AbstractTextFile


class DownloadReportTemplate(RTemplate):
    def __init__(self):
        self.file_type = ".txt"

    @staticmethod
    def request_template() -> Template:
        """
        Define template for this report

        :return: Report Template
        """

        string = "\nDownload data size for request #$id: $size K"

        return Template(string)

    @staticmethod
    def cumulative_template():
        """
        Define template for this report

        :return: Report Template
        """

        string = "\nTotal volume of downloaded data for range $begin to $end: $size K"
        return Template(string)

    def render_template(self, title: str, data: Dict) -> AbstractTextFile:
        """
        render template to file

        :param title: filename
        :param data: data to render
        :return: an AbstractTextFile
        """

        if "id" in data:
            content = Template.substitute(self.request_template(), data)
        else:
            content = Template.substitute(self.cumulative_template(), data)

        return AbstractTextFile(title, content)
